==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/azuredatatransfer/kotlin/inputs/ConnectionPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azuredatatransfer.kotlin.inputs

import com.pulumi.azurenative.azuredatatransfer.inputs.ConnectionPropertiesArgs.builder
import com.pulumi.azurenative.azuredatatransfer.kotlin.enums.Direction
import com.pulumi.azurenative.azuredatatransfer.kotlin.enums.FlowType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Properties of connection
 * @property direction Direction of data movement
 * @property flowTypes The flow types being requested for this connection
 * @property justification Justification for the connection request
 * @property pin PIN to link requests together
 * @property pipeline Pipeline to use to transfer data
 * @property policies The policies for this connection
 * @property primaryContact The primary contact for this connection request
 * @property remoteSubscriptionId Subscription ID to link cloud subscriptions together
 * @property requirementId Requirement ID of the connection
 * @property schemas The schemas for this connection
 * @property secondaryContacts The secondary contacts for this connection request
 */
public data class ConnectionPropertiesArgs(
    public val direction: Output<Either<String, Direction>>? = null,
    public val flowTypes: Output<List<Either<String, FlowType>>>? = null,
    public val justification: Output<String>? = null,
    public val pin: Output<String>? = null,
    public val pipeline: Output<String>,
    public val policies: Output<List<String>>? = null,
    public val primaryContact: Output<String>? = null,
    public val remoteSubscriptionId: Output<String>? = null,
    public val requirementId: Output<String>? = null,
    public val schemas: Output<List<SchemaArgs>>? = null,
    public val secondaryContacts: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.azuredatatransfer.inputs.ConnectionPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.azuredatatransfer.inputs.ConnectionPropertiesArgs =
        com.pulumi.azurenative.azuredatatransfer.inputs.ConnectionPropertiesArgs.builder()
            .direction(
                direction?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .flowTypes(
                flowTypes?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform(
                            { args0 -> args0 },
                            { args0 -> args0.let({ args0 -> args0.toJava() }) },
                        )
                    })
                }),
            )
            .justification(justification?.applyValue({ args0 -> args0 }))
            .pin(pin?.applyValue({ args0 -> args0 }))
            .pipeline(pipeline.applyValue({ args0 -> args0 }))
            .policies(policies?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .primaryContact(primaryContact?.applyValue({ args0 -> args0 }))
            .remoteSubscriptionId(remoteSubscriptionId?.applyValue({ args0 -> args0 }))
            .requirementId(requirementId?.applyValue({ args0 -> args0 }))
            .schemas(
                schemas?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .secondaryContacts(secondaryContacts?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ConnectionPropertiesArgs].
 */
@PulumiTagMarker
public class ConnectionPropertiesArgsBuilder internal constructor() {
    private var direction: Output<Either<String, Direction>>? = null

    private var flowTypes: Output<List<Either<String, FlowType>>>? = null

    private var justification: Output<String>? = null

    private var pin: Output<String>? = null

    private var pipeline: Output<String>? = null

    private var policies: Output<List<String>>? = null

    private var primaryContact: Output<String>? = null

    private var remoteSubscriptionId: Output<String>? = null

    private var requirementId: Output<String>? = null

    private var schemas: Output<List<SchemaArgs>>? = null

    private var secondaryContacts: Output<List<String>>? = null

    /**
     * @param value Direction of data movement
     */
    @JvmName("ktatofafstmximsn")
    public suspend fun direction(`value`: Output<Either<String, Direction>>) {
        this.direction = value
    }

    /**
     * @param value The flow types being requested for this connection
     */
    @JvmName("tgofughfugjqksua")
    public suspend fun flowTypes(`value`: Output<List<Either<String, FlowType>>>) {
        this.flowTypes = value
    }

    @JvmName("pbvctueesvantqrh")
    public suspend fun flowTypes(vararg values: Output<Either<String, FlowType>>) {
        this.flowTypes = Output.all(values.asList())
    }

    /**
     * @param values The flow types being requested for this connection
     */
    @JvmName("dmyinnqfatjwkfyh")
    public suspend fun flowTypes(values: List<Output<Either<String, FlowType>>>) {
        this.flowTypes = Output.all(values)
    }

    /**
     * @param value Justification for the connection request
     */
    @JvmName("hujtavtngxupdvlr")
    public suspend fun justification(`value`: Output<String>) {
        this.justification = value
    }

    /**
     * @param value PIN to link requests together
     */
    @JvmName("pbmulxpbdrnihqrr")
    public suspend fun pin(`value`: Output<String>) {
        this.pin = value
    }

    /**
     * @param value Pipeline to use to transfer data
     */
    @JvmName("xytamocfefbjgibn")
    public suspend fun pipeline(`value`: Output<String>) {
        this.pipeline = value
    }

    /**
     * @param value The policies for this connection
     */
    @JvmName("mcbufoiioexilidl")
    public suspend fun policies(`value`: Output<List<String>>) {
        this.policies = value
    }

    @JvmName("htwlomawyvbshlot")
    public suspend fun policies(vararg values: Output<String>) {
        this.policies = Output.all(values.asList())
    }

    /**
     * @param values The policies for this connection
     */
    @JvmName("gdavliybykohlmmp")
    public suspend fun policies(values: List<Output<String>>) {
        this.policies = Output.all(values)
    }

    /**
     * @param value The primary contact for this connection request
     */
    @JvmName("gxceqrfdnhbpncwm")
    public suspend fun primaryContact(`value`: Output<String>) {
        this.primaryContact = value
    }

    /**
     * @param value Subscription ID to link cloud subscriptions together
     */
    @JvmName("cifqbqvjomootyxs")
    public suspend fun remoteSubscriptionId(`value`: Output<String>) {
        this.remoteSubscriptionId = value
    }

    /**
     * @param value Requirement ID of the connection
     */
    @JvmName("jcdnwfairxndjavc")
    public suspend fun requirementId(`value`: Output<String>) {
        this.requirementId = value
    }

    /**
     * @param value The schemas for this connection
     */
    @JvmName("tncqxtbxhrjqcyfn")
    public suspend fun schemas(`value`: Output<List<SchemaArgs>>) {
        this.schemas = value
    }

    @JvmName("hxpbfnpyiwvtsmap")
    public suspend fun schemas(vararg values: Output<SchemaArgs>) {
        this.schemas = Output.all(values.asList())
    }

    /**
     * @param values The schemas for this connection
     */
    @JvmName("sbtkcxvbflnyjwbk")
    public suspend fun schemas(values: List<Output<SchemaArgs>>) {
        this.schemas = Output.all(values)
    }

    /**
     * @param value The secondary contacts for this connection request
     */
    @JvmName("phgwgtrbbyhqvvji")
    public suspend fun secondaryContacts(`value`: Output<List<String>>) {
        this.secondaryContacts = value
    }

    @JvmName("hbhtmwapmmhyieqw")
    public suspend fun secondaryContacts(vararg values: Output<String>) {
        this.secondaryContacts = Output.all(values.asList())
    }

    /**
     * @param values The secondary contacts for this connection request
     */
    @JvmName("tnteubgfkxkxvimp")
    public suspend fun secondaryContacts(values: List<Output<String>>) {
        this.secondaryContacts = Output.all(values)
    }

    /**
     * @param value Direction of data movement
     */
    @JvmName("tixrkuoefdxrpucc")
    public suspend fun direction(`value`: Either<String, Direction>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.direction = mapped
    }

    /**
     * @param value Direction of data movement
     */
    @JvmName("vgiwtddauyrwbtfw")
    public fun direction(`value`: String) {
        val toBeMapped = Either.ofLeft<String, Direction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.direction = mapped
    }

    /**
     * @param value Direction of data movement
     */
    @JvmName("tdwjqkbsuhrfsneg")
    public fun direction(`value`: Direction) {
        val toBeMapped = Either.ofRight<String, Direction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.direction = mapped
    }

    /**
     * @param value The flow types being requested for this connection
     */
    @JvmName("kjwcsclmifycmlph")
    public suspend fun flowTypes(`value`: List<Either<String, FlowType>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.flowTypes = mapped
    }

    /**
     * @param values The flow types being requested for this connection
     */
    @JvmName("cqaxqhmlidsftryt")
    public suspend fun flowTypes(vararg values: Either<String, FlowType>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.flowTypes = mapped
    }

    /**
     * @param value Justification for the connection request
     */
    @JvmName("crvxmbhyvaujqfgh")
    public suspend fun justification(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.justification = mapped
    }

    /**
     * @param value PIN to link requests together
     */
    @JvmName("pujcqxxwuepngsmp")
    public suspend fun pin(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pin = mapped
    }

    /**
     * @param value Pipeline to use to transfer data
     */
    @JvmName("glbahdqhcuiqgvpn")
    public suspend fun pipeline(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.pipeline = mapped
    }

    /**
     * @param value The policies for this connection
     */
    @JvmName("fcyrukxccbyghnqa")
    public suspend fun policies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.policies = mapped
    }

    /**
     * @param values The policies for this connection
     */
    @JvmName("tfsfaawqnibotbyy")
    public suspend fun policies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.policies = mapped
    }

    /**
     * @param value The primary contact for this connection request
     */
    @JvmName("nlnlnwimbdjdwbbp")
    public suspend fun primaryContact(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.primaryContact = mapped
    }

    /**
     * @param value Subscription ID to link cloud subscriptions together
     */
    @JvmName("brnibktfwupbnfur")
    public suspend fun remoteSubscriptionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.remoteSubscriptionId = mapped
    }

    /**
     * @param value Requirement ID of the connection
     */
    @JvmName("ipubybswevwpatbx")
    public suspend fun requirementId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.requirementId = mapped
    }

    /**
     * @param value The schemas for this connection
     */
    @JvmName("vklteflnekivcewj")
    public suspend fun schemas(`value`: List<SchemaArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.schemas = mapped
    }

    /**
     * @param argument The schemas for this connection
     */
    @JvmName("kwlbhftkkmfxitfx")
    public suspend fun schemas(argument: List<suspend SchemaArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { SchemaArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.schemas = mapped
    }

    /**
     * @param argument The schemas for this connection
     */
    @JvmName("ggpvuppmmubnjwdw")
    public suspend fun schemas(vararg argument: suspend SchemaArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { SchemaArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.schemas = mapped
    }

    /**
     * @param argument The schemas for this connection
     */
    @JvmName("hnhsibtmiktstpme")
    public suspend fun schemas(argument: suspend SchemaArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(SchemaArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.schemas = mapped
    }

    /**
     * @param values The schemas for this connection
     */
    @JvmName("oyrdoakkohykhqkj")
    public suspend fun schemas(vararg values: SchemaArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.schemas = mapped
    }

    /**
     * @param value The secondary contacts for this connection request
     */
    @JvmName("umhiogckymwjlhua")
    public suspend fun secondaryContacts(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secondaryContacts = mapped
    }

    /**
     * @param values The secondary contacts for this connection request
     */
    @JvmName("xvikjxqhdsimomfr")
    public suspend fun secondaryContacts(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.secondaryContacts = mapped
    }

    internal fun build(): ConnectionPropertiesArgs = ConnectionPropertiesArgs(
        direction = direction,
        flowTypes = flowTypes,
        justification = justification,
        pin = pin,
        pipeline = pipeline ?: throw PulumiNullFieldException("pipeline"),
        policies = policies,
        primaryContact = primaryContact,
        remoteSubscriptionId = remoteSubscriptionId,
        requirementId = requirementId,
        schemas = schemas,
        secondaryContacts = secondaryContacts,
    )
}

==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/azuredatatransfer/kotlin/inputs/ConnectionPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azuredatatransfer.kotlin.inputs

import com.pulumi.azurenative.azuredatatransfer.inputs.ConnectionPropertiesArgs.builder
import com.pulumi.azurenative.azuredatatransfer.kotlin.enums.Direction
import com.pulumi.azurenative.azuredatatransfer.kotlin.enums.FlowType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Properties of connection
 * @property direction Direction of data movement
 * @property flowTypes The flow types being requested for this connection
 * @property justification Justification for the connection request
 * @property pin PIN to link requests together
 * @property pipeline Pipeline to use to transfer data
 * @property policies The policies for this connection
 * @property primaryContact The primary contact for this connection request
 * @property remoteSubscriptionId Subscription ID to link cloud subscriptions together
 * @property requirementId Requirement ID of the connection
 * @property schemas The schemas for this connection
 * @property secondaryContacts The secondary contacts for this connection request
 */
public data class ConnectionPropertiesArgs(
    public val direction: Output<Either<String, Direction>>? = null,
    public val flowTypes: Output<List<Either<String, FlowType>>>? = null,
    public val justification: Output<String>? = null,
    public val pin: Output<String>? = null,
    public val pipeline: Output<String>,
    public val policies: Output<List<String>>? = null,
    public val primaryContact: Output<String>? = null,
    public val remoteSubscriptionId: Output<String>? = null,
    public val requirementId: Output<String>? = null,
    public val schemas: Output<List<SchemaArgs>>? = null,
    public val secondaryContacts: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.azuredatatransfer.inputs.ConnectionPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.azuredatatransfer.inputs.ConnectionPropertiesArgs =
        com.pulumi.azurenative.azuredatatransfer.inputs.ConnectionPropertiesArgs.builder()
            .direction(
                direction?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .flowTypes(
                flowTypes?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform(
                            { args0 -> args0 },
                            { args0 -> args0.let({ args0 -> args0.toJava() }) },
                        )
                    })
                }),
            )
            .justification(justification?.applyValue({ args0 -> args0 }))
            .pin(pin?.applyValue({ args0 -> args0 }))
            .pipeline(pipeline.applyValue({ args0 -> args0 }))
            .policies(policies?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .primaryContact(primaryContact?.applyValue({ args0 -> args0 }))
            .remoteSubscriptionId(remoteSubscriptionId?.applyValue({ args0 -> args0 }))
            .requirementId(requirementId?.applyValue({ args0 -> args0 }))
            .schemas(
                schemas?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .secondaryContacts(secondaryContacts?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ConnectionPropertiesArgs].
 */
@PulumiTagMarker
public class ConnectionPropertiesArgsBuilder internal constructor() {
    private var direction: Output<Either<String, Direction>>? = null

    private var flowTypes: Output<List<Either<String, FlowType>>>? = null

    private var justification: Output<String>? = null

    private var pin: Output<String>? = null

    private var pipeline: Output<String>? = null

    private var policies: Output<List<String>>? = null

    private var primaryContact: Output<String>? = null

    private var remoteSubscriptionId: Output<String>? = null

    private var requirementId: Output<String>? = null

    private var schemas: Output<List<SchemaArgs>>? = null

    private var secondaryContacts: Output<List<String>>? = null

    /**
     * @param value Direction of data movement
     */
    @JvmName("mikcpulokbfxxetd")
    public suspend fun direction(`value`: Output<Either<String, Direction>>) {
        this.direction = value
    }

    /**
     * @param value The flow types being requested for this connection
     */
    @JvmName("oeyuuetuwnpergnl")
    public suspend fun flowTypes(`value`: Output<List<Either<String, FlowType>>>) {
        this.flowTypes = value
    }

    @JvmName("cpweeqoromdahfpg")
    public suspend fun flowTypes(vararg values: Output<Either<String, FlowType>>) {
        this.flowTypes = Output.all(values.asList())
    }

    /**
     * @param values The flow types being requested for this connection
     */
    @JvmName("vtkeerjwwqjfraue")
    public suspend fun flowTypes(values: List<Output<Either<String, FlowType>>>) {
        this.flowTypes = Output.all(values)
    }

    /**
     * @param value Justification for the connection request
     */
    @JvmName("ptidrjgrqdvksron")
    public suspend fun justification(`value`: Output<String>) {
        this.justification = value
    }

    /**
     * @param value PIN to link requests together
     */
    @JvmName("nwmqktojlaflrfbm")
    public suspend fun pin(`value`: Output<String>) {
        this.pin = value
    }

    /**
     * @param value Pipeline to use to transfer data
     */
    @JvmName("sdrmwjhxglanbhhv")
    public suspend fun pipeline(`value`: Output<String>) {
        this.pipeline = value
    }

    /**
     * @param value The policies for this connection
     */
    @JvmName("jilqoljjsbvnhyjv")
    public suspend fun policies(`value`: Output<List<String>>) {
        this.policies = value
    }

    @JvmName("fwewrempswstvgin")
    public suspend fun policies(vararg values: Output<String>) {
        this.policies = Output.all(values.asList())
    }

    /**
     * @param values The policies for this connection
     */
    @JvmName("kviigvmakyavvtrw")
    public suspend fun policies(values: List<Output<String>>) {
        this.policies = Output.all(values)
    }

    /**
     * @param value The primary contact for this connection request
     */
    @JvmName("xgbpilojtwtvwuqe")
    public suspend fun primaryContact(`value`: Output<String>) {
        this.primaryContact = value
    }

    /**
     * @param value Subscription ID to link cloud subscriptions together
     */
    @JvmName("nookpieewmbhopqy")
    public suspend fun remoteSubscriptionId(`value`: Output<String>) {
        this.remoteSubscriptionId = value
    }

    /**
     * @param value Requirement ID of the connection
     */
    @JvmName("duvwfgaomtebwsll")
    public suspend fun requirementId(`value`: Output<String>) {
        this.requirementId = value
    }

    /**
     * @param value The schemas for this connection
     */
    @JvmName("qcneirhbekqkqvln")
    public suspend fun schemas(`value`: Output<List<SchemaArgs>>) {
        this.schemas = value
    }

    @JvmName("vobnaqoqdvwopixq")
    public suspend fun schemas(vararg values: Output<SchemaArgs>) {
        this.schemas = Output.all(values.asList())
    }

    /**
     * @param values The schemas for this connection
     */
    @JvmName("tieoigiifpqlqqsy")
    public suspend fun schemas(values: List<Output<SchemaArgs>>) {
        this.schemas = Output.all(values)
    }

    /**
     * @param value The secondary contacts for this connection request
     */
    @JvmName("heewuvsqkhvwejlo")
    public suspend fun secondaryContacts(`value`: Output<List<String>>) {
        this.secondaryContacts = value
    }

    @JvmName("hmihkwwoyqmorohj")
    public suspend fun secondaryContacts(vararg values: Output<String>) {
        this.secondaryContacts = Output.all(values.asList())
    }

    /**
     * @param values The secondary contacts for this connection request
     */
    @JvmName("jmfrqdstcxgdrssl")
    public suspend fun secondaryContacts(values: List<Output<String>>) {
        this.secondaryContacts = Output.all(values)
    }

    /**
     * @param value Direction of data movement
     */
    @JvmName("ohvcfsxntfxupelh")
    public suspend fun direction(`value`: Either<String, Direction>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.direction = mapped
    }

    /**
     * @param value Direction of data movement
     */
    @JvmName("yacckqessuekodgt")
    public fun direction(`value`: String) {
        val toBeMapped = Either.ofLeft<String, Direction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.direction = mapped
    }

    /**
     * @param value Direction of data movement
     */
    @JvmName("vmsyocuvwusywlug")
    public fun direction(`value`: Direction) {
        val toBeMapped = Either.ofRight<String, Direction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.direction = mapped
    }

    /**
     * @param value The flow types being requested for this connection
     */
    @JvmName("vwqwumoymanlqupp")
    public suspend fun flowTypes(`value`: List<Either<String, FlowType>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.flowTypes = mapped
    }

    /**
     * @param values The flow types being requested for this connection
     */
    @JvmName("mlhncdofdikhyocj")
    public suspend fun flowTypes(vararg values: Either<String, FlowType>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.flowTypes = mapped
    }

    /**
     * @param value Justification for the connection request
     */
    @JvmName("iyxiecglqypyxvkn")
    public suspend fun justification(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.justification = mapped
    }

    /**
     * @param value PIN to link requests together
     */
    @JvmName("wrmowfucpyejvnoc")
    public suspend fun pin(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pin = mapped
    }

    /**
     * @param value Pipeline to use to transfer data
     */
    @JvmName("yrvvmyxypbgfaerf")
    public suspend fun pipeline(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.pipeline = mapped
    }

    /**
     * @param value The policies for this connection
     */
    @JvmName("nwrslsaljclehutv")
    public suspend fun policies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.policies = mapped
    }

    /**
     * @param values The policies for this connection
     */
    @JvmName("tfqxukfyfieraqvh")
    public suspend fun policies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.policies = mapped
    }

    /**
     * @param value The primary contact for this connection request
     */
    @JvmName("npuwjqpphngilpwt")
    public suspend fun primaryContact(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.primaryContact = mapped
    }

    /**
     * @param value Subscription ID to link cloud subscriptions together
     */
    @JvmName("bwtwktvmcesjlpgk")
    public suspend fun remoteSubscriptionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.remoteSubscriptionId = mapped
    }

    /**
     * @param value Requirement ID of the connection
     */
    @JvmName("kdwnouynatbifssy")
    public suspend fun requirementId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.requirementId = mapped
    }

    /**
     * @param value The schemas for this connection
     */
    @JvmName("mpauregusyaaulkc")
    public suspend fun schemas(`value`: List<SchemaArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.schemas = mapped
    }

    /**
     * @param argument The schemas for this connection
     */
    @JvmName("ehhbynmqmioaomqc")
    public suspend fun schemas(argument: List<suspend SchemaArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { SchemaArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.schemas = mapped
    }

    /**
     * @param argument The schemas for this connection
     */
    @JvmName("emerodlxblvscvgw")
    public suspend fun schemas(vararg argument: suspend SchemaArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { SchemaArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.schemas = mapped
    }

    /**
     * @param argument The schemas for this connection
     */
    @JvmName("abipybvwsygcvqkm")
    public suspend fun schemas(argument: suspend SchemaArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(SchemaArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.schemas = mapped
    }

    /**
     * @param values The schemas for this connection
     */
    @JvmName("khqeiiiudrnijdhd")
    public suspend fun schemas(vararg values: SchemaArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.schemas = mapped
    }

    /**
     * @param value The secondary contacts for this connection request
     */
    @JvmName("nkcromudymuosbol")
    public suspend fun secondaryContacts(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secondaryContacts = mapped
    }

    /**
     * @param values The secondary contacts for this connection request
     */
    @JvmName("cbgaqdgqxviovgij")
    public suspend fun secondaryContacts(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.secondaryContacts = mapped
    }

    internal fun build(): ConnectionPropertiesArgs = ConnectionPropertiesArgs(
        direction = direction,
        flowTypes = flowTypes,
        justification = justification,
        pin = pin,
        pipeline = pipeline ?: throw PulumiNullFieldException("pipeline"),
        policies = policies,
        primaryContact = primaryContact,
        remoteSubscriptionId = remoteSubscriptionId,
        requirementId = requirementId,
        schemas = schemas,
        secondaryContacts = secondaryContacts,
    )
}
